==> tencentcloud-sdk-python-memcached-3.0.437.tar.gz: tencentcloud-sdk-python-memcached-3.0.437/tencentcloud/memcached/v20190318/memcached_client.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.memcached.v20190318 import models


class MemcachedClient(AbstractClient):
    _apiVersion = '2019-03-18'
    _endpoint = 'memcached.tencentcloudapi.com'
    _service = 'memcached'


    def DescribeInstances(self, request):
        """获取Cmem实例列表

        :param request: Request instance for DescribeInstances.
        :type request: :class:`tencentcloud.memcached.v20190318.models.DescribeInstancesRequest`
        :rtype: :class:`tencentcloud.memcached.v20190318.models.DescribeInstancesResponse`

        """
        try:
            params = request._serialize()
            body = self.call("DescribeInstances", params)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeInstancesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)

==> tencentcloud-sdk-python-memcached-3.0.1266.tar.gz: tencentcloud-sdk-python-memcached-3.0.1266/tencentcloud/memcached/v20190318/memcached_client.py <==
# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.memcached.v20190318 import models


class MemcachedClient(AbstractClient):
    _apiVersion = '2019-03-18'
    _endpoint = 'memcached.tencentcloudapi.com'
    _service = 'memcached'


    def DescribeInstances(self, request):
        """获取Cmem实例列表

        :param request: Request instance for DescribeInstances.
        :type request: :class:`tencentcloud.memcached.v20190318.models.DescribeInstancesRequest`
        :rtype: :class:`tencentcloud.memcached.v20190318.models.DescribeInstancesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeInstances", params, headers=headers)
            response = json.loads(body)
            model = models.DescribeInstancesResponse()
            model._deserialize(response["Response"])
            return model
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(type(e).__name__, str(e))
